clc
clear all
close all

%%
% Input info for the simply suported beam
L = 100; %Length of beam [m]
b = 0.1; %width of beam [m]
h = 0.1; %heigth of beam [m]
Dens = 7850; %density of steel [kg/m^3]
m = Dens*b*h; %mass of the beam [kg/m]
E = 2.10e+11; %Stiffness [N/m^2]
I = (1/12)*b*h^3; %Second moment of area [m^4]

% Calculation of relevant factors for the Rayleigh damping
om_p = ((pi/L)^2)*sqrt(E*I/m);
om_r = ((10*pi/L)^2)*sqrt(E*I/m);
xi1 = 0.05;
xi2 = 0.05;
alpha = (2*om_p*om_r*((om_p*xi2)-(om_r*xi1))/((om_p^2)-(om_r^2)));
beta = 2*((om_p*xi1)-(om_r*xi2))/((om_p^2)-(om_r^2));

% Input info on the moving force
F_car = 1000; %Force [N]
V_car = 10; % speed [km/t]
v_car = V_car/3.6; % speed [m/s]

% Additional input for the analysis
x = L/2;
t_max = L/v_car;
t_inc = 0.001*t_max;
t = linspace(0,t_max,ceil(t_max/t_inc));
u = t*0;

for n=1:2
    om_n = ((n*pi/L)^2)*sqrt(E*I/m);
    Om_n = n*pi*v_car/L;
    beta_n = Om_n/om_n;
    % Introduce Rayleigh damping
    xi_n = (1/2)*((alpha/om_n)+(beta*om_n));
    if xi_n < 1
        om_dn = om_n*sqrt(1-(xi_n)^2);
        u1 = (2*F_car*(L^3)*sin(n*pi*x/L))/(E*I*(n^4)*(pi^4)*(((1-(beta_n)^2)^2) + ((2*xi_n*beta_n)^2)));
        u2 = (2*xi_n*beta_n*cos(Om_n*t)) - ((1-(beta_n^2))*sin(Om_n*t));
        u3 = (exp(-xi_n*om_n*t)).*((beta_n*(1-(beta_n^2)-(2*(xi_n^2)))*(sin(om_n*t))/(sqrt(1-(xi_n^2)))) - (2*xi_n*beta_n*cos(om_n*t)));
    u = u + (u1*(u2 + u3));
    u = double(u);
    else
        fprintf('%s %.0f \n','The damping ratio is larger or equal to 1, mode',n)
    end
end

u_max=max(abs(u));
  

AnalyticalSolution = figure(1)
hold on
plot(t,u,'k--')
hold off
xlabel('t [s]','FontSize',24);
ylabel('u [m]','FontSize',24);
legend1 = legend('Analytical solution', 'location', 'notheast');
set(legend1,'FontSize',16);

