function trafficAcceleration(section,nIntervals)
% TRAFFICACCELERATION Creates vectors for the time interval 
% and sets the date for a recording.
%
% INPUT:    section:        Specifying the section for analysis
%           nIntervals:     Number of time intervals
%

% Loading complete recording from Hardanger Bridge
load('Recording'); 

[~,~,t] = setDate(recording);
H = readAcceleration(recording);

% Defining information for time of recording
l = length(t)/nIntervals;

time(1) = t(1);
for i=1:nIntervals
    time(i+1) = ceil(t(i*l));
end

H = H{section};

% Reshaping the vectors for time and response
H = reshape(H,[],nIntervals);
t = reshape(t,[],nIntervals);

% Plotting the vertical acceleration response
for i=1:nIntervals
    y(i) = figure;
    plot(t(:,i),H(:,i),'DurationTickFormat','hh:mm','LineWidth',1)
    ylabel('$$\ddot{u}_{z} [m/s^{2}]$$',...
        'interpreter','latex')
    set(gca,'FontSize',24,'Ylim',[-0.1 0.1],'LineWidth',2,...
        'Ytick',-0.1:0.05:0.1)
%     saveas(y(i),fullfile('Figures','Acceleration',...
%         sprintf('%s-%s',datestr(time(i),'HH.MM'),...
%         datestr(time(i+1),'HH.MM')),...
%         sprintf('Section_H%d.png',section)))
end
    





